<?php
/**
 * @file
 * Administrative page callbacks for the Mobile Switch module.
 */

function mobile_switch_settings_form() {
  drupal_add_js(drupal_get_path('module', 'mobile_switch') . '/js/mobile_switch.admin.js', array('scope' => 'footer'));

  $form = array();
  $active_themes = array_merge(array('none' => t('Do not use')), mobile_switch_get_themes());

  $form['global_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Mobile Switch settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE
  );
  $form['global_settings']['mobile_switch_mobile_theme'] = array(
    '#type' => 'select',
    '#title' => t('Mobile theme'),
    '#description' => t('Which theme should be used as default theme when a mobile device detected.'),
    '#options' => $active_themes,
    '#default_value' => variable_get('mobile_switch_mobile_theme', 'none')
  );
  $form['global_settings']['mobile_switch_deskbrowser'] = array(
    '#type' => 'select',
    '#title' => t('Desktop browser'),
    '#description' => t('Using with desktop browsers.'),
    '#options' => array(
      TRUE => t('Yes'),
      FALSE => t('No')
    ),
    '#default_value' => variable_get('mobile_switch_deskbrowser', 1)
  );
  $form['global_settings']['mobile_switch_developer'] = array(
    '#type' => 'select',
    '#title' => t('Developer modus'),
    '#description' => t('Extends the browser detection for desktop emulators such as <em>Opera mobile</em>, <em>Fennec</em> or more other. Don\'t use it on production sites.'),
    '#options' => array(
      FALSE => t('No'),
      TRUE => t('Yes')
    ),
    '#default_value' => variable_get('mobile_switch_developer', 0)
  );
  $form['global_settings']['advanced'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced developer modus settings'),
    '#collapsible' => TRUE,
    '#collapsed' => variable_get('mobile_switch_display_useragent', 0) ? FALSE : TRUE,
    '#states' => array(
      'visible' => array(
        ':input[name="mobile_switch_developer"]' => array('value' => '1')
      )
    )
  );
  $form['global_settings']['advanced']['mobile_switch_emulator_strings'] = array(
    '#type' => 'textarea',
    '#title' => t('Mobile emulator identification'),
    '#description' => "Configure user agent string parts. Use ONLY letters - no other characters! DO NOT use the '*' wildcard character! Enter one string per line. As example the default string parts: <pre>Fennec\nAndroid\nTablet\nMobi</pre>",
    '#default_value' => variable_get('mobile_switch_emulator_strings', "Fennec\nAndroid\nTablet\nMobi"),
    '#required' => TRUE
  );
  // variable_get('mobile_switch_display_useragent', TRUE)
  $form['global_settings']['advanced']['mobile_switch_display_useragent'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display user agent'),
    '#description' => t('Use this function to display a message that contains a user agent string. Do not forget to turn off this option. For the display is required: the permissions %administer-site-configuration or %administer-themes.', array('%administer-site-configuration' => t('Administer site configuration'), '%administer-themes' => t('Administer themes'))),
    '#default_value' => variable_get('mobile_switch_display_useragent', 0)
  );

  return system_settings_form($form);
}
